


# Environmental bias in phenotypic selection gradients----

library(pedantics) 


                              ##########################################################
                              #                                                        #
                              #     1.0 Load model with Robertson-Price Identity----   #
                              #                                                        #
                              ##########################################################

RPI<- readRDS("") 

summary(RPI)
diag(autocorr(RPI$VCV)[2,,]) 
max(diag(autocorr(RPI$VCV)[2,,]))
min(diag(autocorr(RPI$VCV)[2,,]))




                                ##########################################################
                                #                                                        #
                                #           2.0 Genetic selection gradients----          #
                                #                                                        #
                                ##########################################################

# The following code is a simplified (univariate) version of the code provided in 
# Stinchcombe, J. R., Simonsen, A. K., & Blows, M. W. (2014). Estimating uncertainty in 
# multivariate responses to selection. Evolution, 68(4), 1188-1196.

#create an index for Va for trait:
Gindex <- c(4)
dimnames(RPI$VCV)[[2]][Gindex]
#check that the sample G's will be symmetric
#change final values to be number of traits minus 1
matrix(as.numeric(RPI$VCV[1,Gindex]),1, 1)
#export the G.mat object
G.mat <- as.matrix(RPI$VCV[,Gindex])
#summary statistics
colMeans(G.mat)
#create CSV file with posterior G matrices
write.csv(G.mat,file="G.mat.csv")


#Repeat for Sg
#Change values of sindex as necessary to ensure sindex contains genetic covariances 
#between traits and fitness.
sgindex <- c(2)
dimnames(RPI$VCV)[[2]][sgindex]
#check that the sample sg is in the right form
matrix(as.numeric(RPI$VCV[1,sgindex]),1,1)
#export the Sg object
Sg <- as.matrix(RPI$VCV[,sgindex])
#summary statistics
colMeans(Sg)
#Create CSV file with posterior sg
write.csv(Sg,file="Sg.csv")


#Loop statement to estimate Beta-g for the posterior distributions
Beta_g <- matrix(NA,dim(RPI$VCV)[1],1)
for (i in 1:dim(RPI$VCV)[1]){
  G.samp <- matrix(as.numeric(RPI$VCV[i,Gindex]),1, 1)
  Sg.samp <- matrix(as.numeric(RPI$VCV[i,sgindex]),1, 1)
  Beta_g [i,]<- t(solve(G.samp) %*% Sg.samp)
}

#Make plots
plot(as.mcmc(Beta_g))
#Summary Statistics
colMeans(Beta_g)
posterior.mode(as.mcmc(Beta_g))
HPDinterval(as.mcmc(Beta_g))
#Write CSV file
write.csv(Beta_g,file="beta_g.csv")


                                  ##########################################################
                                  #                                                        #
                                  #        3.0 Environmental selection gradients----       #
                                  #                                                        #
                                  ##########################################################

# Create an index for cohort matrix:
Cohort.index <- c(8)
dimnames(RPI$VCV)[[2]][Cohort.index]
#check that the sample G's will be symmetric
#change final values to be number of traits minus 1
matrix(as.numeric(RPI$VCV[1,Cohort.index]),1, 1)
#export the G.mat object
Cohort.mat <- as.matrix(RPI$VCV[,Cohort.index])
#summary statistics
colMeans(Cohort.mat)
#create CSV file with posterior PE matrices
write.csv(Cohort.mat ,file="Cohort.mat.csv")


# Repeat for Cohort covariance----
#Change values of sindex as necessary to ensure sindex contains PE covariances 
#between traits and fitness.
SCohort.index <- c(6)
dimnames(RPI$VCV)[[2]][SCohort.index]
#check that the sample sg is in the right form
matrix(as.numeric(RPI$VCV[1,SCohort.index]),1,1)
#export the Sg object
SCohort<- as.matrix(RPI$VCV[,SCohort.index])
#summary statistics
colMeans(SCohort)
#Create CSV file with posterior spe
write.csv(SCohort,file="SCohort.csv")


#Loop statement to estimate Beta-g for the posterior distributions
Beta_Cohort <- matrix(NA,dim(RPI$VCV)[1], 1)
for (i in 1:dim(RPI$VCV)[1]){
  PE.samp <- matrix(as.numeric(RPI$VCV[i,Cohort.index]), 1, 1)
  Spe.samp <- matrix(as.numeric(RPI$VCV[i,SCohort.index]), 1, 1)
  Beta_Cohort [i,]<- t(solve(PE.samp) %*% Spe.samp)
}

#Make plots
plot(as.mcmc(Beta_Cohort))
#Summary Statistics
colMeans(Beta_Cohort)
posterior.mode(as.mcmc(Beta_Cohort))
HPDinterval(as.mcmc(Beta_Cohort))
#Write CSV file
write.csv(Beta_Cohort,file="Beta_Cohort.csv")



#create an index for maternal effects matrix:
Mindex <- c(12)
dimnames(RPI$VCV)[[2]][Mindex]
#check that the sample M's will be symmetric
#change final values to be number of traits minus 1
matrix(as.numeric(RPI$VCV[1,Mindex]),1, 1)
#export the M.mat object
M.mat <- as.matrix(RPI$VCV[,Mindex])
#summary statistics
colMeans(M.mat)
#create CSV file with posterior R matrices
write.csv(M.mat,file="M.mat.csv")


#Repeat for maternal covariance----
#Change values of sindex as necessary to ensure sindex contains r covariances 
#between traits and fitness.
smindex <- c(10)
dimnames(RPI$VCV)[[2]][smindex]
#check that the sample sg is in the right form
matrix(as.numeric(RPI$VCV[1,smindex]),1,1)
#export the Sg object
Sm <- as.matrix(RPI$VCV[,smindex])
#summary statistics
colMeans(Sm)
#Create CSV file with posterior sr
write.csv(Sm,file="Sm.csv")


#Loop statement to estimate Beta-g for the posterior distributions
Beta_m <- matrix(NA,dim(RPI$VCV)[1],1)
for (i in 1:dim(RPI$VCV)[1]){
  m.samp <- matrix(as.numeric(RPI$VCV[i,Mindex]),1, 1)
  Sm.samp <- matrix(as.numeric(RPI$VCV[i,smindex]),1, 1)
  Beta_m [i,]<- t(solve(m.samp) %*% Sm.samp)
}

#Summary Statistics
plot(as.mcmc(Beta_m))
colMeans(Beta_m)
posterior.mode(as.mcmc(Beta_m))
HPDinterval(as.mcmc(Beta_m))


#create an index for residual matrix:
Rindex <- c(16)
dimnames(RPI$VCV)[[2]][Rindex]
#check that the sample R's will be symmetric
#change final values to be number of traits minus 1
matrix(as.numeric(RPI$VCV[1,Rindex]),1, 1)
#export the R.mat object
R.mat <- as.matrix(RPI$VCV[,Rindex])
#summary statistics
colMeans(R.mat)
#create CSV file with posterior R matrices
write.csv(R.mat,file="R.mat.csv")


#Repeat for residual covariance----
#Change values of sindex as necessary to ensure sindex contains r covariances 
#between traits and fitness.
srindex <- c(14)
dimnames(RPI$VCV)[[2]][srindex]
#check that the sample sg is in the right form
matrix(as.numeric(RPI$VCV[1,srindex]),1, 1)
#export the Sg object
Sr <- as.matrix(RPI$VCV[,srindex])
#summary statistics
colMeans(Sr)
#Create CSV file with posterior sr
write.csv(Sr,file="Sg.csv")


#Loop statement to estimate Beta-e for the posterior distributions
Beta_r <- matrix(NA,dim(RPI$VCV)[1], 1)
for (i in 1:dim(RPI$VCV)[1]){
  r.samp <- matrix(as.numeric(RPI$VCV[i,Rindex]),1, 1)
  Sr.samp <- matrix(as.numeric(RPI$VCV[i,srindex]),1, 1)
  Beta_r [i,]<- t(solve(r.samp) %*% Sr.samp)
}

#Summary Statistics
plot(as.mcmc(Beta_r))
colMeans(Beta_r)
posterior.mode(as.mcmc(Beta_r))
HPDinterval(as.mcmc(Beta_r))



                                    ##########################################################
                                    #                                                        #
                                    #        4.0 Combine environmental matrices----          #
                                    #                                                        #
                                    ##########################################################

## Combining PE and R into E matrix:
E.mat <- Cohort.mat + M.mat + R.mat
# Check that these two are the same:
colMeans(Cohort.mat) + colMeans(M.mat) + colMeans(R.mat)
colMeans(E.mat)
#create CSV file with posterior R matrices
write.csv(E.mat,file="E.mat.csv")
#Repeat for Se
Se <- SCohort + Sm + Sr 
# Check that these two are the same:
colMeans(SCohort) + colMeans(Sm) + colMeans(Sr)
colMeans(Se)
#Create CSV file with posterior sr
write.csv(Se,file="Se.csv")


#Loop statement to estimate Beta-e for the posterior distributions
Beta_e <- matrix(NA,dim(RPI$VCV)[1],dim(Se)[2])
for (i in 1:dim(RPI$VCV)[1]){
  Cohort.samp <- matrix(as.numeric(RPI$VCV[i,Cohort.index]),1, 1)
  SCohort.samp <- matrix(as.numeric(RPI$VCV[i,SCohort.index ]),1,1)
  m.samp <- matrix(as.numeric(RPI$VCV[i,Mindex]),1, 1)
  Sm.samp <- matrix(as.numeric(RPI$VCV[i,smindex]), 1, 1)
  r.samp <- matrix(as.numeric(RPI$VCV[i,Rindex]), 1, 1)
  Sr.samp <- matrix(as.numeric(RPI$VCV[i,srindex]), 1, 1)
  e.samp <- Cohort.samp + m.samp + r.samp 
  Se.samp <- SCohort.samp + Sm.samp + Sr.samp
  Beta_e [i,]<- t(solve(e.samp) %*% Se.samp)
}


#Make plots
plot(as.mcmc(Beta_e))
#Summary Statistics
colMeans(Beta_e)
posterior.mode(as.mcmc(Beta_e))
HPDinterval(as.mcmc(Beta_e))
#Write CSV file
write.csv(Beta_e,file="beta_e.csv")


# difference in betaG and betaE
deltaB <- Beta_e - Beta_g 
posterior.mode(as.mcmc(deltaB)) ; HPDinterval(as.mcmc(deltaB))
plot(as.mcmc(deltaB))
table(deltaB>0)/4500 

plot(density(as.mcmc(deltaB)), main = "", xlab = "")
abline(v=0, col = "red", lty = "dotted", lwd = 3)

# BS:
x<- c(posterior.mode(as.mcmc(Beta_g))[1], HPDinterval(as.mcmc(Beta_g))[1,], 
      posterior.mode(as.mcmc(Beta_Cohort))[1], HPDinterval(as.mcmc(Beta_Cohort))[1,], 
      posterior.mode(as.mcmc(Beta_m))[1], HPDinterval(as.mcmc(Beta_m))[1,],
      posterior.mode(as.mcmc(Beta_r))[1], HPDinterval(as.mcmc(Beta_r))[1,],
      posterior.mode(as.mcmc(Beta_e))[1], HPDinterval(as.mcmc(Beta_e))[1,],
      posterior.mode(as.mcmc(deltaB))[1], HPDinterval(as.mcmc(deltaB))[1,]
)


write.table(x, "clipboard", sep="\t")
