



# Quantitative genetic analyses---



# Initial data cleaning----
setwd("C:\\Users\\osullivanr\\Desktop\\Code and data for submission\\Quantitative genetics chapter - All code and data\\Analyses and Data\\Data")


# Function to plot posterior modes and HPD intervals----
plot.estimates <- function(x) {
  if (class(x) != "summary.mcmc")
    x <- summary(x)
  n <- dim(x$statistics)[1]
  par(mar=c(2, 7, 4, 1))
  plot(x$statistics[,1], n:1,
       yaxt="n", ylab="",
       xlim=range(x$quantiles)*1.2,
       pch=19,
       main="Posterior means and 95% credible intervals")
  grid()
  axis(2, at=n:1, rownames(x$statistics), las=2)
  arrows(x$quantiles[,1], n:1, x$quantiles[,5], n:1, code=0)
  abline(v=0, lty=2)
}






                                  ##########################################################
                                  #                                                        #
                                  #                    Load packages----                   #
                                  #                                                        #
                                  ##########################################################

  library(pedantics)
  library(MasterBayes)
  library(plyr) 
  library(dplyr) 
  library(ggplot2) 
  library(gridExtra)
  library(MASS)
  library(readr)
  library(reshape)
  library(QGglmm)
  library(mgcv)
  library(lme4)
  library(arsenal)
  



Pedigree_Final <- read_csv("Pedigree_Final.csv")
newdata<- Pedigree_Final[c(2:17)]






                            ##########################################################
                            #                                                        #
                            #     1.0 Extract required columns from pedigree----     #
                            #                                                        #
                            ##########################################################


Salmon<- as.data.frame(newdata[c(2:4, 5, 11, 16)])  
names(Salmon)[1]<- "id"  


  
                            ##########################################################
                            #                                                        #
                            #                 2.0 Create pedigree----                #
                            #                                                        #
                            ##########################################################

# 2.1 Extract ids, dams, and sires----
Ped<- Salmon[1:3]


# 2.2 Fix pedigree----
Fish.fixed<- fixPedigree(Ped = Ped, dat = Salmon[, c(1, 4:6)])
head(Fish.fixed)
dim(Fish.fixed)
names(Fish.fixed)[4]<- "Sex"
names(Fish.fixed)[5]<- "w"
names(Fish.fixed)[6]<- "cohort"



# 2.3 Plot to see if pedigree is correct----
dev.off()
Salmon.Pedigree<- subset(Fish.fixed, cohort!='NA')
dim(Fish.fixed); dim(Salmon.Pedigree)
drawPedigree(Salmon.Pedigree, cohorts=Salmon.Pedigree$cohort, writeCohortLabels = "y",dots='y', cohortLabs.cex = 0.8)

Fish.stats<- pedigreeStats(Ped=Fish.fixed[, 1:3], cohorts=Fish.fixed$Year_of_Spawning,lowMem=FALSE, graphicalReport = "n")
pedStatSummary(Fish.stats)




                              ##########################################################
                              #                                                        #
                              #                     3.0 Get SRL----                    #
                              #                                                        #
                              ##########################################################

# 3.1 Load sex-specific portions of pedigree----
Females <- read_csv("Females.csv")
Males <- read_csv("Males.csv")

# 3.2 Standardize return length across ALL YEARS----
Females$SRL<- (Females$Length - mean(Females$Length))/sd(Females$Length)
Males$SRL<- (Males$Length - mean(Males$Length))/sd(Males$Length)

# 3.3 Extract SRL and id columns----
Females2<- Females[, c(3, 24)] ; names(Females2)[1]<- "id"

Males2<- Males[, c(3, 24)] ; names(Males2)[1]<- "id"


######################### Recreate pedigree!! ########################
df<- list(Salmon, Females2, Males2)
Salmon2<- merge_recurse(df)
names(Salmon2)[6]<- "cohort"
write.csv(Salmon2, file = "Salmon2.csv")

# Extract ids, dams, and sires----
Ped2<- Salmon2[1:3]
compare(Ped2, Ped)

# Fix pedigree----
Fish.fixed<- fixPedigree(Ped = Ped2, dat = Salmon2[, c(1, 4, 5, 6, 7)])
head(Fish.fixed)
dim(Fish.fixed)
names(Fish.fixed)[4]<- "Sex"
names(Fish.fixed)[5]<- "w"
names(Fish.fixed)[6]<- "cohort"
names(Fish.fixed)[7]<- "SRL"
head(Fish.fixed)
names(Fish.fixed)[1]<- "animal"

Ped3<- insertPed(Ped2, founders = NULL)
Ped4<- orderPed(Ped3)

# Plot to see if pedigree is correct----
dev.off()
Salmon.Pedigree<- subset(Fish.fixed, cohort!='NA')
dim(Fish.fixed); dim(Salmon.Pedigree)
drawPedigree(Salmon.Pedigree[1:3], cohorts=Salmon.Pedigree$cohort, writeCohortLabels = "y",dots='y', cohortLabs.cex = 0.8)






                                ##########################################################
                                #                                                        #
                                #       4.0 BLUP and Robertson-Price analyses----        #
                                #                                                        #
                                ##########################################################

# 4.1 Define priors----
Priors1<-list(G=list(G1=list(V=0.1, nu=0.0001, alpha.mu=0,alpha.V=1000),
                     G2=list(V=0.1, nu=0.0001, alpha.mu=0,alpha.V=1000),
                     G3=list(V=0.1, nu=0.0001, alpha.mu=0,alpha.V=1000)),
                      R=list(V=0.1, nu=0.0001))

Priors2<-list(G=list(G1=list(V=0.1, nu=0.1, alpha.mu=0,alpha.V=1000),
                     G2=list(V=0.1, nu=0.1, alpha.mu=0,alpha.V=1000)),
              R=list(V=0.1, nu=0.1))

Bivariate.priors <- list(G = list(G1 = list(V = diag(2), n = 1.002, alpha.mu=rep(0, 2), alpha.V=diag(2)*1000),
                                  G2 = list(V = diag(2), n = 1.002, alpha.mu=rep(0, 2), alpha.V=diag(2)*1000),
                                  G3 = list(V = diag(2), n = 1.002, alpha.mu=rep(0, 2), alpha.V=diag(2)*1000)),
                         R = list(V = diag(2), n=1.002))



# 4.2 Separate sexes for univariate analyses----
Females.BLUP<- subset(Salmon2, Sex == "1") ; names(Females.BLUP)[1]<- "animal"
Males.BLUP<- subset(Salmon2, Sex == "0")   ; names(Males.BLUP)[1]<- "animal"

# No need to remove grilse as males are not used in quantitative genetic analyses----

# 4.3 Determine if the trait is heritable by looking for significant Va----
BLUP.Female<- MCMCglmm(SRL~1, 
                random = ~animal+cohort+dam,
                data = Females.BLUP,
                pedigree = Ped4,
                rcov = ~units,
                prior = Priors1,
                pr=TRUE, nitt=2500000, burnin=500000, thin=1000)

BLUP.Female2<- MCMCglmm(SRL~1, 
                       random = ~animal+cohort+dam,
                       data = Females.BLUP,
                       pedigree = Ped4,
                       rcov = ~units,
                       prior = Priors1,
                       pr=TRUE, nitt=2500000, burnin=500000, thin=1000)

summary(BLUP.Female)
plot(BLUP.Female)
posterior.mode(BLUP.Female$VCV[,"animal"])
HPDinterval(BLUP.Female$VCV[,"animal"])

diag(autocorr(BLUP.Female$VCV)[2,,]) 

autocorr.plot(as.mcmc(BLUP.Female$Sol[, "(Intercept)"]))
autocorr.plot(as.mcmc(BLUP.Female$VCV[, "animal"]))
autocorr.plot(as.mcmc(BLUP.Female$VCV[, "cohort"]))
autocorr.plot(as.mcmc(BLUP.Female$VCV[, "dam"]))
autocorr.plot(as.mcmc(BLUP.Female$VCV[, "units"]))


gelman.diag(mcmc.list(BLUP.Female$Sol, BLUP.Female2$Sol), multivariate = FALSE)
gelman.diag(mcmc.list(BLUP.Female$VCV, BLUP.Female2$VCV), multivariate = FALSE)
plot.estimates(mcmc.list(BLUP.Female$Sol, BLUP.Female2$Sol))

par(mfrow=c(3,2), mar=c(2, 1, 1, 1))
plot(mcmc.list(BLUP.Female$VCV, BLUP.Female2$VCV), ask=F, auto.layout=F)
par(mfrow=c(1,1))


# 4.4 Calculate the heritability of body size----
Female.BS.h <- BLUP.Female$VCV[,"animal"]/(BLUP.Female$VCV[,"animal"]+
                                             BLUP.Female$VCV[,"cohort"]+
                                             BLUP.Female$VCV[,"dam"]+
                                             BLUP.Female$VCV[, "units"])

posterior.mode(Female.BS.h)
HPDinterval(Female.BS.h)

Females_ID<- Females[c(3, 9)]
Females.BLUP2<- merge(Females.BLUP, Females_ID, by = "animal")



# 4.5 Determine if fitness is heritable by looking for significant Va in lifetime reproductive success----
BLUP2.Female<- MCMCglmm(Number_of_Offspring~1, 
                       random = ~animal+cohort+dam,
                       data = Females.BLUP2,
                       pedigree = Ped4,
                       rcov = ~units,
                       prior = Priors1,
                       family = "poisson",
                       pr=TRUE, nitt=15000000, burnin=1000000, thin=10000)

BLUP2.Female2<- MCMCglmm(Number_of_Offspring~1, 
                        random = ~animal+cohort+dam,
                        data = Females.BLUP2,
                        pedigree = Ped4,
                        rcov = ~units,
                        prior = Priors1,
                        family = "poisson",
                        pr=TRUE, nitt=15000000, burnin=1000000, thin=10000)



summary(BLUP2.Female)
plot(BLUP2.Female)
posterior.mode(BLUP2.Female$VCV[,"animal"])
HPDinterval(BLUP2.Female$VCV[,"animal"])

autocorr.plot(as.mcmc(BLUP2.Female$Sol[, "(Intercept)"]))
autocorr.plot(as.mcmc(BLUP2.Female$VCV[, "animal"]))
autocorr.plot(as.mcmc(BLUP2.Female$VCV[, "cohort"]))
autocorr.plot(as.mcmc(BLUP2.Female$VCV[, "dam"]))
autocorr.plot(as.mcmc(BLUP2.Female$VCV[, "units"]))


gelman.diag(mcmc.list(BLUP2.Female$Sol, BLUP2.Female2$Sol), multivariate = FALSE)
plot.estimates(mcmc.list(BLUP2.Female$Sol, BLUP2.Female2$Sol))

setwd("")
saveRDS(BLUP.Female, file = "TraitVa_1.rds")
saveRDS(BLUP.Female2, file = "TraitVa_2.rds")
saveRDS(BLUP2.Female, file = "FitnessVa_1.rds")
saveRDS(BLUP2.Female2, file = "FitnessVa_2.rds")


# 4.6 Heritability of fitness for females on the latent scale----
Female.LRS.h <- BLUP2.Female$VCV[,"animal"]/(BLUP2.Female$VCV[,"animal"]+
                                               BLUP2.Female$VCV[,"cohort"]+
                                               BLUP2.Female$VCV[,"dam"]+
                                               BLUP2.Female$VCV[, "units"])

posterior.mode(Female.LRS.h)
HPDinterval(Female.LRS.h)


# 4.7 Heritability of fitness on the data scale----
df<- data.frame(mu = as.vector(BLUP2.Female[["Sol"]][,'(Intercept)']),
                va = as.vector(BLUP2.Female[["VCV"]][,'animal']),
                vp = rowSums(BLUP2.Female[["VCV"]]))

post.females <- do.call("rbind", apply(df, 1, function(row){
  QGparams(mu = row[["mu"]],
           var.a = row[["va"]],
           var.p = row[["vp"]],
           model = "Poisson.log", verbose = FALSE)
}))

mean(as.mcmc(post.females$var.a.obs))
HPDinterval(as.mcmc(post.females$var.a.obs))
print(heritability.fitness.females<- (posterior.mode(as.mcmc(post.females$h2.obs))))
print(heritability.fitness.females.CI<- (HPDinterval(as.mcmc(post.females$h2.obs))))




# 4.8 Robertson-Price indentity
{Female.RP<- MCMCglmm(cbind(Number_of_Offspring, SRL)~trait-1, 
                     random = ~us(trait):animal+us(trait):cohort+us(trait):dam,
                     rcov = ~us(trait):units, 
                     family = c("poisson", "gaussian"),
                     pedigree = Ped4,
                     data = Females.BLUP2,
                     prior = Bivariate.priors,
                     nitt=5000000, burnin=500000, thin=1000)

Female.RP2<- MCMCglmm(cbind(Number_of_Offspring, SRL)~trait-1, 
                     random = ~us(trait):animal+us(trait):cohort+us(trait):dam,
                     rcov = ~us(trait):units, 
                     family = c("poisson", "gaussian"),
                     pedigree = Ped4,
                     data = Females.BLUP2,
                     prior = Bivariate.priors,
                     nitt=5000000, burnin=500000, thin=1000)
}
summary(Female.RP)
plot(Female.RP)

diag(autocorr(Female.RP$VCV)[2,,]) 
gelman.diag(mcmc.list(Female.RP$VCV, Female.RP2$VCV), multivariate = FALSE)

par(mfrow=c(8,2), mar=c(2, 1, 1, 1))
plot(mcmc.list(Female.RP$VCV, Female.RP2$VCV), ask=F, auto.layout=F)
par(mfrow=c(1,1))


posterior.mode(Female.RP$VCV[,3])
HPDinterval(Female.RP$VCV[, 3])

saveRDS(Female.RP, file = "RP.rds")
saveRDS(Female.RP2, file = "RP2.rds")

setwd("")

write.csv(Females.BLUP, "Female_Plotting.csv")
write.csv(Ped4, "Ped4.csv")


