



# Script for tables----


setwd("C:\\Users\\osullivanr\\Desktop\\Code and data for submission\\Quantitative genetics chapter - All code and data\\Analyses and Data\\Data")



# Load packages----
library(readr)
library(ggplot2)
library(dplyr)
library(MASS) 
library(MCMCglmm)
library(gridExtra)
library(psych)
library(Hmisc)
library(sandwich)
library(car)
library(lme4)
library(broom)
library(parallel)
library(splines)
library(QGglmm)


# Load data and examine its structure
Females <- read_csv("Females.csv")
Males<- read_csv("Males.csv")

str(Females) ; str(Males)
Females$Sex<- as.factor(Females$Sex) ; Males$Sex<- as.factor(Males$Sex)
Females$cohort<- as.numeric(Females$cohort) ; Males$cohort<- as.numeric(Males$cohort)
dim(Females); dim(Males)

# Standardized return length across ALL YEARS----
Females$SRL<- (Females$Length - mean(Females$Length))/sd(Females$Length)
Males2<- Males[! grepl("G", Males$animal), ]
Males2$SRL<- (Males2$Length - mean(Males2$Length))/sd(Males2$Length)






                                ##########################################################
                                #                                                        #
                                #                   1.0 Table A3----                     #
                                #                                                        #
                                ##########################################################

# 1.1 Calculate basic statistics for females----
# Length
mean.size.female <- with(Females, tapply(Length, list(Year_of_Spawning), mean, na.rm=T)) 
sd.size.female <- with(Females, tapply(Length, list(Year_of_Spawning), sd, na.rm=T)) 
n.size.female <- with(Females, tapply(Length, list(Year_of_Spawning), length)) 
se.size.female <- sd.size.female/sqrt(n.size.female) 


barplot(mean.size.female)
mids<- barplot(mean.size.female,                 
               xlab="Cohort",             
               ylab="Length (cm)",             
               ylim=c(0,70),                
               cex.names=1.1,                 
               cex.lab=1.2,                
               cex.axis=1.1)
arrows(x0=mids, y0=mean.size.female - se.size.female, 
       x1=mids, y1=mean.size.female + se.size.female,      
       code = 3,angle = 90, length=0.1) 


# LRS
mean.LRS.female <- with(Females, tapply(Number_of_Offspring, list(Year_of_Spawning), mean, na.rm=T)) 
sd.LRS.female <- with(Females, tapply(Number_of_Offspring, list(Year_of_Spawning), sd, na.rm=T)) 
n.LRS.female <- with(Females, tapply(Number_of_Offspring, list(Year_of_Spawning), length)) 
se.LRS.female <- sd.LRS.female/sqrt(n.LRS.female) 

barplot(mean.LRS.female)
mids<- barplot(mean.LRS.female,                 
               xlab="Cohort",             
               ylab="Absolute fitness",             
               ylim=c(0, 1.6),                
               cex.names=1.1,                 
               cex.lab=1.2,                
               cex.axis=1.1)
arrows(x0=mids, y0=mean.LRS.female - se.LRS.female, 
       x1=mids, y1=mean.LRS.female + se.LRS.female,      
       code = 3,angle = 90, length=0.1) 




# 1.2 Calculate basic statistics for males----
# Length
mean.size.male <- with(Males2, tapply(Length, list(Year_of_Spawning), mean, na.rm=T)) 
sd.size.male <- with(Males2, tapply(Length, list(Year_of_Spawning), sd, na.rm=T)) 
n.size.male <- with(Males2, tapply(Length, list(Year_of_Spawning), length)) 
se.size.male <- sd.size.male/sqrt(n.size.male) 


barplot(mean.size.male)
mids<- barplot(mean.size.male,                 
               xlab="Cohort",             
               ylab="Length (cm)",             
               ylim=c(0,70),                
               cex.names=1.1,                 
               cex.lab=1.2,                
               cex.axis=1.1)
arrows(x0=mids, y0=mean.size.male - se.size.male, 
       x1=mids, y1=mean.size.male + se.size.male,      
       code = 3,angle = 90, length=0.1) 


# LRS
mean.LRS.male <- with(Males2, tapply(Number_of_Offspring, list(Year_of_Spawning), mean, na.rm=T)) 
sd.LRS.male <- with(Males2, tapply(Number_of_Offspring, list(Year_of_Spawning), sd, na.rm=T)) 
n.LRS.male <- with(Males2, tapply(Number_of_Offspring, list(Year_of_Spawning), length)) 
se.LRS.male <- sd.LRS.male/sqrt(n.LRS.male) 

barplot(mean.LRS.male)
mids<- barplot(mean.LRS.male,                 
               xlab="Cohort",             
               ylab="Absolute fitness",             
               ylim=c(0, 1.5),                
               cex.names=1.1,                 
               cex.lab=1.2,                
               cex.axis=1.1)
arrows(x0=mids, y0=mean.LRS.male - se.LRS.male, 
       x1=mids, y1=mean.LRS.male + se.LRS.male,      
       code = 3,angle = 90, length=0.1) 







                                ##########################################################
                                #                                                        #
                                #                     2.0 Table 2----                    #
                                #                                                        #
                                ##########################################################

Selection_Females<- readRDS("")

summary(Selection_Females)
posterior.mode(Selection_Females)

Trait<- readRDS("")

summary(Trait)



# Calculate the heritability of body size----
Female.BS.h <- Trait$VCV[,"animal"]/(Trait$VCV[,"animal"]+
                                       Trait$VCV[,"cohort"]+
                                       Trait$VCV[,"dam"]+
                                       Trait$VCV[, "units"])
posterior.mode(Female.BS.h)
HPDinterval(Female.BS.h)


# Calculate percentage of variance explanined by dams----
Female.Dam.variance<- Trait$VCV[,"dam"]/(Trait$VCV[,"animal"]+
                                       Trait$VCV[,"cohort"]+
                                       Trait$VCV[,"dam"]+
                                       Trait$VCV[, "units"])
posterior.mode(Female.Dam.variance)
HPDinterval(Female.Dam.variance)


# Calculate percentage of variance explanined by cohort----
Female.Dam.cohort.variance<- Trait$VCV[,"cohort"]/(Trait$VCV[,"animal"]+
                                                   Trait$VCV[,"cohort"]+
                                                   Trait$VCV[,"dam"]+
                                                   Trait$VCV[, "units"])
posterior.mode(Female.Dam.cohort.variance)
HPDinterval(Female.Dam.cohort.variance)

# Calculate percentage of variance explanined by residual variance----
Female.Dam.units.variance<- Trait$VCV[,"units"]/(Trait$VCV[,"animal"]+
                                                 Trait$VCV[,"cohort"]+
                                                 Trait$VCV[,"dam"]+
                                                 Trait$VCV[, "units"])
posterior.mode(Female.Dam.units.variance)
HPDinterval(Female.Dam.units.variance)



Fitness<- readRDS("")



# 2.2 Heritability of fitness for females on the latent scale----
Female.LRS.h <- Fitness$VCV[,"animal"]/(Fitness$VCV[,"animal"]+
                                          Fitness$VCV[,"cohort"]+
                                          Fitness$VCV[,"dam"]+
                                          Fitness$VCV[, "units"])

posterior.mode(Female.LRS.h)
HPDinterval(Female.LRS.h)


# 2.3 Heritability of fitness on the data scale----
df<- data.frame(mu = as.vector(Fitness[["Sol"]][,'(Intercept)']),
                va = as.vector(Fitness[["VCV"]][,'animal']),
                vp = rowSums(Fitness[["VCV"]]))

post.females <- do.call("rbind", apply(df, 1, function(row){
  QGparams(mu = row[["mu"]],
           var.a = row[["va"]],
           var.p = row[["vp"]],
           model = "Poisson.log", verbose = FALSE)
}))

posterior.mode(as.mcmc(post.females$var.a.obs))
HPDinterval(as.mcmc(post.females$var.a.obs))
print(heritability.fitness.females<- (posterior.mode(as.mcmc(post.females$h2.obs))))
print(heritability.fitness.females.CI<- (HPDinterval(as.mcmc(post.females$h2.obs))))

Va2<- Fitness$VCV[, "animal"]
posterior.mode(Va2)
HPDinterval(Va2)

cohort2<- Fitness$VCV[, "cohort"]
posterior.mode(cohort2)
HPDinterval(cohort2)

dam2<- Fitness$VCV[, "dam"]
posterior.mode(dam2)
HPDinterval(dam2)

units2<- Fitness$VCV[, "units"]
posterior.mode(units2)
HPDinterval(units2)



                                    ##########################################################
                                    #                                                        #
                                    #                     3.0 Table A2----                   #
                                    #                                                        #
                                    ##########################################################

# 3.1 Read in full pedigree (all fish and cohorts)----
Historical_Pedigree_Analysis <- read_csv("")

Pedigree<- Historical_Pedigree_Analysis[, -1]

# 3.2 Subset data by sex----
Females<- Pedigree[which(Pedigree$Sex == "F"), ]
Males<- Pedigree[which(Pedigree$Sex == "M"), ]

# All fish
n.size.all.fish <- with(Pedigree, tapply(ID, list(Year_of_Spawning), length)) ; print(n.size.all.fish)

# Subset by provenance
Wild<- Pedigree[which(Pedigree$Provenance == "W"), ]
Hatchery<- Pedigree[which(Pedigree$Provenance == "FC"), ]

n.size.wild <- with(Wild, tapply(ID, list(Year_of_Spawning), length)) ; print(n.size.wild)
n.size.hatchery<- with(Hatchery, tapply(ID, list(Year_of_Spawning), length)) ; print(n.size.hatchery)
Pedigree$Provenance<- as.factor(Pedigree$Provenance)


# Females
# Size
mean.size.female <- with(Females, tapply(Length, list(Year_of_Spawning), mean, na.rm=T)) ; print(mean.size.female)
sd.size.female <- with(Females, tapply(Length, list(Year_of_Spawning), sd, na.rm=T)) 
n.size.female <- with(Females, tapply(Length, list(Year_of_Spawning), length)) ; print(n.size.female)
se.size.female <- sd.size.female/sqrt(n.size.female) ; print(se.size.female)

# LRS
mean.LRS.female <- with(Females, tapply(Number_of_Offspring, list(Year_of_Spawning), mean, na.rm=T)) ; print(mean.LRS.female)
sd.LRS.female <- with(Females, tapply(Number_of_Offspring, list(Year_of_Spawning), sd, na.rm=T)) 
n.LRS.female <- with(Females, tapply(Number_of_Offspring, list(Year_of_Spawning), length)) ; print(sd.LRS.female)
se.LRS.female <- sd.LRS.female/sqrt(n.LRS.female) ; print(se.LRS.female)



# Males----
# Size
mean.size.male <- with(Males, tapply(Length, list(Year_of_Spawning), mean, na.rm=T)) ; print(mean.size.male)
sd.size.male <- with(Males, tapply(Length, list(Year_of_Spawning), sd, na.rm=T)) 
n.size.male <- with(Males, tapply(Length, list(Year_of_Spawning), length)) ; print(n.size.male)
se.size.male <- n.size.male/sqrt(n.size.male) ; print(se.size.male)

# LRS
mean.LRS.male <- with(Males, tapply(Number_of_Offspring, list(Year_of_Spawning), mean, na.rm=T)) ; print(mean.LRS.male)
sd.LRS.male <- with(Males, tapply(Number_of_Offspring, list(Year_of_Spawning), sd, na.rm=T)) ; print(sd.LRS.male) 
n.LRS.male <- with(Males, tapply(Number_of_Offspring, list(Year_of_Spawning), length)) ; print(sd.LRS.female)
se.LRS.male <- sd.LRS.male/sqrt(n.LRS.male) ; print(se.LRS.male)








