



# Building of dataframe to analyse the pedigree----




                          ##########################################################
                          #                                                        #
                          #     1.0 Run the below files to load the pedigree----   #                                                                   #                                                        #
                          ##########################################################

setwd("")
load("BURRphenP4")
load("BURRgenoP4")
load("bothLODframe3")


# 1.1 Set main working directory. This is where the final dataframe will be saved to----
setwd("")




                          ##########################################################
                          #                                                        #
                          #               2.0 Clean bothLODframe3----              #
                          #                                                        #
                          ##########################################################

View(bothLODframe3)

# 2.1 Subset out required columns and check data structure----
bothLODframe3_Cleaned<- bothLODframe3[,c(1, 4, 15)]
str(bothLODframe3_Cleaned)

# 2.2 Rename the offspring column to 'ID' so that dataframes can be merged----
names(bothLODframe3_Cleaned)[1]<- 'ID'


                          ##########################################################
                          #                                                        #
                          #                3.0 Clean BURRgenoP4----                #
                          #                                                        #
                          ##########################################################

View(BURRgenoP4)

# 3.1 Subset out required columns and check data structure----
BURRgenoP4_Cleaned<- as.data.frame( BURRgenoP4[, c(1, 7)])
str(BURRgenoP4_Cleaned)

# 3.2 Rename variables----
names(BURRgenoP4_Cleaned)[1]<- 'ID'
names(BURRgenoP4_Cleaned)[2]<- 'Sex'


                          ##########################################################
                          #                                                        #
                          #                4.0 Clean BURRphenP4----                #
                          #                                                        #
                          ##########################################################

View(BURRphenP4)

# 4.1 Subset out the required columns and check data structure----
BURRphenP4_Cleaned<- BURRphenP4[, c(1, 5, 6, 10, 13, 14, 16)]
str(BURRphenP4_Cleaned)


# 4.2 Code 'WFC2', 'YearSPW', and 'fert' as factors----
{
with(BURRphenP4_Cleaned, 
     as.factor(WFC2))
with(BURRphenP4_Cleaned, 
     as.factor(YearSPW))
with(BURRphenP4_Cleaned, 
     as.factor(fert))
}


# 4.3 Rename the variables so their titles are more descriptive----
{
names(BURRphenP4_Cleaned)[1]<- 'ID'
names(BURRphenP4_Cleaned)[2]<- 'Provenance'
names(BURRphenP4_Cleaned)[3]<- 'Length'
names(BURRphenP4_Cleaned)[7]<- 'Year_of_Fertilization'
}




                                ##########################################################
                                #                                                        #
                                #                  5.0 Clean modPOS1----                 #
                                #                                                        #
                                ##########################################################

names(modPOS1)[1]<- 'ID'
modPOS1_Cleaned<- modPOS1[, c(1, 7)]





                                  ##########################################################
                                  #                                                        #
                                  #        6.0 Merge all 4 dataframes together----         #
                                  #                                                        #
                                  ##########################################################


# 6.1 Merge dataframes----
Pedigree_Data_Cleaned<- merge(modPOS1_Cleaned, merge(bothLODframe3_Cleaned, merge(BURRgenoP4_Cleaned, BURRphenP4_Cleaned, by="ID", all.x=TRUE, all.y=TRUE), by = "ID", all.x = TRUE, all.y = TRUE), by = "ID", all.x = TRUE, all.y = TRUE)


# 6.2 Rename variables so their titles are more descriptive----
{
names(Pedigree_Data_Cleaned)[2]<- 'Number_of_Offspring'
names(Pedigree_Data_Cleaned)[3]<- 'Dam'
names(Pedigree_Data_Cleaned)[4]<- 'Sire'
names(Pedigree_Data_Cleaned)[9]<- 'Sea_Winters'
}

Historical_Pedigree<- Pedigree_Data_Cleaned






                                  ##########################################################
                                  #                                                        #
                                  #   7.0 Correct spawning and fertilization columns----   #
                                  #                                                        #
                                  ##########################################################

# 7.1. Create column with correct spawning year----
Historical_Pedigree$Year_of_Spawning<- as.numeric(Historical_Pedigree$YearSPW)-1


# 7.2 Create column with correct fertilization year----
Historical_Pedigree$Year_of_Fertilization<- as.numeric(Historical_Pedigree$Year_of_Fertilization)-1





                                  ##########################################################
                                  #                                                        #
                                  #      8.0 Check for dams as sires, and vice-versa----   #
                                  #                                                        #
                                  ##########################################################



# 8.1 Do any dams appear as sires and vice-versa?----
a<- as.data.frame(Historical_Pedigree$Dam[Historical_Pedigree$Dam %in% Historical_Pedigree$Sire]) ; names(a)[1]<- "Matches"
levels(as.factor(a$Matches))

b<- as.data.frame(Historical_Pedigree$Sire[Historical_Pedigree$Sire %in% Historical_Pedigree$Dam]) ; names(b)[1]<- "Matches"
levels(as.factor(b$Matches))
# The fish BURR_WK_86_041 appears as a dam 4 times and as a sire once. Remove record as a sire----

Historical_Pedigree$Sire[Historical_Pedigree$Sire == "BURR_WK_86_041"]<- "NA"


# 8.2 Export dataframe----
write.csv(Historical_Pedigree, 'Historical_Pedigree_Analysis.csv')









